==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/CalendarDateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarDateDescription } from "./CalendarDateDescription";
/**
 * @hidden
 */
export let CalendarDateDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalendarDateDescriptionMetadata extends Base {
        static b(a) {
            if (CalendarDateDescriptionMetadata.a == null) {
                CalendarDateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalendarDateDescriptionMetadata.c(CalendarDateDescriptionMetadata.a);
            }
            if (a.j(CalendarDateDescriptionMetadata.a)) {
                return;
            }
            a.y(CalendarDateDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Date", "Date");
            a.item("IsCurrentMonth", "Boolean");
            a.item("IsPrevMonth", "Boolean");
            a.item("IsNextMonth", "Boolean");
        }
        static d(a) {
            CalendarDateDescriptionMetadata.b(a);
            a.aa("CalendarDate", () => new CalendarDateDescription());
            a.z("CalendarDate", CalendarDateDescriptionMetadata.a);
        }
    }
    CalendarDateDescriptionMetadata.$t = /*@__PURE__*/ markType(CalendarDateDescriptionMetadata, 'CalendarDateDescriptionMetadata');
    CalendarDateDescriptionMetadata.a = null;
    return CalendarDateDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CalendarDateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarDateDescription } from "./CalendarDateDescription";
/**
 * @hidden
 */
export let CalendarDateDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalendarDateDescriptionMetadata extends Base {
        static b(a) {
            if (CalendarDateDescriptionMetadata.a == null) {
                CalendarDateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalendarDateDescriptionMetadata.c(CalendarDateDescriptionMetadata.a);
            }
            if (a.k(CalendarDateDescriptionMetadata.a)) {
                return;
            }
            a.aa(CalendarDateDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Date", "Date");
            a.item("IsCurrentMonth", "Boolean");
            a.item("IsPrevMonth", "Boolean");
            a.item("IsNextMonth", "Boolean");
        }
        static d(a) {
            CalendarDateDescriptionMetadata.b(a);
            a.ac("CalendarDate", () => new CalendarDateDescription());
            a.ab("CalendarDate", CalendarDateDescriptionMetadata.a);
        }
    }
    CalendarDateDescriptionMetadata.$t = /*@__PURE__*/ markType(CalendarDateDescriptionMetadata, 'CalendarDateDescriptionMetadata');
    CalendarDateDescriptionMetadata.a = null;
    return CalendarDateDescriptionMetadata;
})();
